pub struct WindDeflection(pub f64);Expand description
Wind deflection of a bullet in inches (in)
This struct represents the bullet’s wind deflection.
Tuple Fields
0: f64Implementations
Sourceimpl WindDeflection
impl WindDeflection
Sourcepub fn calculate() -> WindDeflectionCalculateBuilder
pub fn calculate() -> WindDeflectionCalculateBuilder
Calculates the wind deflection of a bullet.
This function determines how much a crosswind will deflect a bullet from its path during flight.
Parameters
lag_time: The lag time of the bullet in seconds.crosswind_speed: The speed of the crosswind in miles per hour (mph).
Returns
A WindDeflection instance representing the wind deflection in inches.